NormLimitRegularizer
====================

.. currentmodule:: pykeen.regularizers

.. autoclass:: NormLimitRegularizer
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~NormLimitRegularizer.forward

   .. rubric:: Methods Documentation

   .. automethod:: forward
